@@ -140,16 +140,13 @@ class QRCodeAdmin(admin.ModelAdmin):
         """
         if request.method == 'POST':
             download = request.GET['download']
-            print(download)
             pks = [int(x) for x in download.split(',')]
-            print(pks)
             if request.user.is_superuser:
                 codes = QRCode.objects.filter(pk__in=pks).all()
             else:
                 codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
             form = QrGenerateForm(data=request.POST)
             if form.is_valid():
-                print(codes)
                 zf = generate_qr_zip(codes, form)
                 resp = HttpResponse(zf, content_type="application/x-zip-compressed")
                 resp[
@@ -167,9 +164,10 @@ class QRCodeAdmin(admin.ModelAdmin):
         else:
             pks = request.session.get('codes_to_download')
             if request.user.is_superuser:
-                codes = QRCode.objects.filter(pk__in=pks).all()
+                codes = QRCode.objects.only('id', 'title').filter(pk__in=pks).all()
             else:
-                codes = QRCode.objects.filter(pk__in=pks, department__in=request.user.departments.all()).all()
+                codes = QRCode.objects.only('id', 'title').filter(pk__in=pks,
+                                                                  department__in=request.user.departments.all()).all()
             context = dict(
                 self.admin_site.each_context(request),
                 is_nav_sidebar_enabled=False,
@@ -207,7 +205,7 @@ class ApiCallAdmin(admin.ModelAdmin):
 
     def change_view(self, request, object_id, form_url='', extra_context=None):
         extra_context = self._get_extra_context(request, extra_context=extra_context)
-        return super(ApiCallAdmin, self).add_view(request, form_url=form_url, extra_context=extra_context)
+        return super(ApiCallAdmin, self).change_view(request, object_id, form_url=form_url, extra_context=extra_context)
 
     def add_view(self, request, form_url='', extra_context=None):
         extra_context = self._get_extra_context(request, extra_context=extra_context)
