@@ -117,12 +117,18 @@ class ApiCall(models.Model):
                                  validators=[validate_is_api_mode_qrcode])
     payload = models.TextField()
 
+    def __str__(self):
+        return f'link: {self.link_url_id}: {self.url}'
+
 
 class Header(models.Model):
     api_call = models.ForeignKey(ApiCall, on_delete=models.CASCADE, related_name='headers')
     key = models.CharField(max_length=128)
     value = models.CharField(max_length=128)
 
+    def __str__(self):
+        return f'{self.key}'
+
 
 def random_string():
     alphabet = string.ascii_lowercase + string.digits
