@@ -2,13 +2,14 @@ from django.urls import reverse
 from rest_framework.renderers import TemplateHTMLRenderer, JSONRenderer
 from rest_framework.response import Response
 from rest_framework.exceptions import NotAuthenticated
-from .models import ApiHit, QRCode
+from .models import ApiHit, QRCode, LinkUrl
 from django.http import Http404, HttpResponse
 from django.conf import settings
 from rest_framework.views import APIView
 from django.shortcuts import redirect
 from django.core.exceptions import ValidationError
 from django.views.generic import DetailView
+from django.shortcuts import get_object_or_404
 import uuid
 import logging
 
@@ -58,7 +59,6 @@ class QRCodeDetails(APIView):
 
     def get(self, request, short_uuid=None, format=None):
         qrcode = self.get_object(short_uuid=short_uuid)
-        handle_api_calls(qrcode)
 
         if request.accepted_renderer.format == 'json' or format == 'json':
             hit = ApiHit(
@@ -90,6 +90,10 @@ class QRCodeDetails(APIView):
                 hit = ApiHit(code=qrcode, action=ApiHit.ACTION_CHOICES.BASIC_INFO)
                 hit.save()
                 return Response({'qrcode': qrcode}, template_name='qrtoolkit_core/qrcode/index.html')
+            if qrcode.mode == QRCode.REDIRECT_MODE_CHOICES.API_CALL:
+                hit = ApiHit(code=qrcode, action=ApiHit.ACTION_CHOICES.API_CALL)
+                hit.save()
+                return Response({'qrcode': qrcode}, template_name='qrtoolkit_core/qrcode/kiosk_call.html')
 
             return Response({'qrcode': qrcode}, template_name='qrtoolkit_core/qrcode/index.html')
 
@@ -99,16 +103,22 @@ class QRCodeDetails(APIView):
         return redirect(to=f'{settings.API_URL}/qrcodes/{qrcode.id}/', permanent=False)
 
 
-def handle_api_calls(code):
+def link_url_clicked(request, pk):
+    u = get_object_or_404(LinkUrl, pk=pk)
+    handle_api_calls(u)
+    return redirect(to=u.url, permanent=False)
+
+
+def handle_api_calls(url):
     """
     If the code has apicalls configured, fire them off.
-    :type code: QRCode
+    :type url: LinkUrl
     """
     import requests
-    for api_call in code.api_calls.all():
+    for api_call in url.api_calls.all():
         headers = {}
         for header in api_call.headers.all():
             headers[header.key] = header.value
-        logger.info(f'posting api_call from {code.title} to {api_call.url}')
+        logger.info(f'posting api_call from {url.name} to {api_call.url}')
         r = requests.post(api_call.url, api_call.payload, headers=headers)
         logger.info(f'response: {r.content.decode("utf-8")}, status_code: {r.status_code}')
